# arpes.constants module

Useful constants for experiments and some useful science facts Much of
this is collected from past students, especially Jeff’s ‘Cstes.ipf’

Some of this will disappear in future updates, as we move away from
magic constants towards bundling necessary information on endstation
classes.

**arpes.constants.mode\_has\_spin\_resolution(mode)**

**arpes.constants.mode\_has\_time\_resolution(mode)**
